Index: trunk/psModules/src/config/pmConfigCamera.c
===================================================================
--- trunk/psModules/src/config/pmConfigCamera.c	(revision 15788)
+++ trunk/psModules/src/config/pmConfigCamera.c	(revision 16611)
@@ -24,18 +24,18 @@
 
 // Generate the skycell version of a named camera configuration
-bool pmConfigCameraSkycellVersion(psMetadata *site, // The site configuration
+bool pmConfigCameraSkycellVersion(psMetadata *system, // The system configuration
                                   const char *name // Name of the un-mosaicked camera
                                   )
 {
-    PS_ASSERT_METADATA_NON_NULL(site, false);
+    PS_ASSERT_METADATA_NON_NULL(system, false);
     PS_ASSERT_STRING_NON_EMPTY(name, false);
 
     bool mdok;                          // Status of MD lookup
-    psMetadata *cameras = psMetadataLookupMetadata(&mdok, site, "CAMERAS"); // List of cameras
+    psMetadata *cameras = psMetadataLookupMetadata(&mdok, system, "CAMERAS"); // List of cameras
     if (!mdok || !cameras) {
-        psError(PS_ERR_UNEXPECTED_NULL, true, "Unable to find CAMERAS in the site configuration.\n");
-        return false;
-    }
-    if (!pmConfigGenerateSkycellVersion(cameras, cameras, name, site)) {
+        psError(PS_ERR_UNEXPECTED_NULL, true, "Unable to find CAMERAS in the system configuration.\n");
+        return false;
+    }
+    if (!pmConfigGenerateSkycellVersion(cameras, cameras, name, system)) {
         psError(PS_ERR_UNKNOWN, true, "Failed to build skycell camera description for %s\n", name);
         return false;
@@ -45,12 +45,12 @@
 
 
-bool pmConfigCameraSkycellVersionsAll(psMetadata *site)
-{
-    PS_ASSERT_METADATA_NON_NULL(site, false);
+bool pmConfigCameraSkycellVersionsAll(psMetadata *system)
+{
+    PS_ASSERT_METADATA_NON_NULL(system, false);
 
     bool mdok;                          // Status of MD lookup
-    psMetadata *cameras = psMetadataLookupMetadata(&mdok, site, "CAMERAS"); // List of cameras
+    psMetadata *cameras = psMetadataLookupMetadata(&mdok, system, "CAMERAS"); // List of cameras
     if (!mdok || !cameras) {
-        psError(PS_ERR_UNEXPECTED_NULL, true, "Unable to find CAMERAS in the site configuration.\n");
+        psError(PS_ERR_UNEXPECTED_NULL, true, "Unable to find CAMERAS in the system configuration.\n");
         return false;
     }
@@ -61,5 +61,5 @@
     while ((camerasItem = psMetadataGetAndIncrement(camerasIter))) {
         assert(camerasItem->type == PS_DATA_METADATA); // Only metadata are allowed here!
-        if (!pmConfigGenerateSkycellVersion(cameras, new, camerasItem->name, site)) {
+        if (!pmConfigGenerateSkycellVersion(cameras, new, camerasItem->name, system)) {
             psError(PS_ERR_UNKNOWN, true, "Failed to build skycell camera description for %s\n",
                     camerasItem->name);
@@ -92,5 +92,5 @@
 static const char *skycellConceptName(const char *name, // Name of concept
                                       const char **concepts, // List of concepts NOT to update
-                                      const psMetadata *site // Site configuration
+                                      const psMetadata *system // System configuration
                                       )
 {
@@ -101,9 +101,9 @@
     }
 
-    if (!site) {
+    if (!system) {
         return name;
     }
     bool mdok;                          // Status of MD lookup
-    psMetadata *skycells = psMetadataLookupMetadata(&mdok, site, "SKYCELLS"); // Skycell concept headers
+    psMetadata *skycells = psMetadataLookupMetadata(&mdok, system, "SKYCELLS"); // Skycell concept headers
     if (!skycells) {
         return name;
@@ -121,5 +121,5 @@
                                     psMetadata *newCameras, // New list of camera configurations
                                     const char *name, // Name of original camera configuration
-                                    const psMetadata *site // Site configuration
+                                    const psMetadata *system // System configuration
                                     )
 {
@@ -213,5 +213,5 @@
         iter = psListIteratorAlloc(concepts, PS_LIST_HEAD, false);
         while ((name = psListGetAndIncrement(iter))) {
-            const char *new = skycellConceptName(name, skycellConceptsFPA, site); // Name for skycell
+            const char *new = skycellConceptName(name, skycellConceptsFPA, system); // Name for skycell
             if (new) {
                 psMetadataAddStr(translation, PS_LIST_TAIL, name, 0, NULL, new);
@@ -224,5 +224,5 @@
         iter = psListIteratorAlloc(concepts, PS_LIST_HEAD, false);
         while ((name = psListGetAndIncrement(iter))) {
-            const char *new = skycellConceptName(name, skycellConceptsChip, site); // Name for skycell
+            const char *new = skycellConceptName(name, skycellConceptsChip, system); // Name for skycell
             if (new) {
                 psMetadataAddStr(translation, PS_LIST_TAIL, name, 0, NULL, new);
@@ -235,5 +235,5 @@
         iter = psListIteratorAlloc(concepts, PS_LIST_HEAD, false);
         while ((name = psListGetAndIncrement(iter))) {
-            const char *new = skycellConceptName(name, skycellConceptsCell, site); // Name for skycell
+            const char *new = skycellConceptName(name, skycellConceptsCell, system); // Name for skycell
             if (new) {
                 psMetadataAddStr(translation, PS_LIST_TAIL, name, 0, NULL, new);
@@ -299,15 +299,15 @@
 
 // Generate the Chip and FPA mosaicked version of a named camera configuration
-bool pmConfigCameraMosaickedVersions(psMetadata *site, // The site configuration
+bool pmConfigCameraMosaickedVersions(psMetadata *system, // The system configuration
                                      const char *name // Name of the un-mosaicked camera
                                     )
 {
-    PS_ASSERT_METADATA_NON_NULL(site, false);
+    PS_ASSERT_METADATA_NON_NULL(system, false);
     PS_ASSERT_STRING_NON_EMPTY(name, false);
 
     bool mdok;                          // Status of MD lookup
-    psMetadata *cameras = psMetadataLookupMetadata(&mdok, site, "CAMERAS"); // List of cameras
+    psMetadata *cameras = psMetadataLookupMetadata(&mdok, system, "CAMERAS"); // List of cameras
     if (!mdok || !cameras) {
-        psError(PS_ERR_UNEXPECTED_NULL, true, "Unable to find CAMERAS in the site configuration.\n");
+        psError(PS_ERR_UNEXPECTED_NULL, true, "Unable to find CAMERAS in the system configuration.\n");
         return false;
     }
@@ -325,12 +325,12 @@
 // the operation putting the new entries first is now implemented in pmConfigGenerateMosaickedVersion
 // Generate the Chip and FPA mosaicked version of a named camera configuration
-bool pmConfigCameraMosaickedVersionsAll(psMetadata *site)
-{
-    PS_ASSERT_METADATA_NON_NULL(site, false);
+bool pmConfigCameraMosaickedVersionsAll(psMetadata *system)
+{
+    PS_ASSERT_METADATA_NON_NULL(system, false);
 
     bool mdok;                          // Status of MD lookup
-    psMetadata *cameras = psMetadataLookupMetadata(&mdok, site, "CAMERAS"); // List of cameras
+    psMetadata *cameras = psMetadataLookupMetadata(&mdok, system, "CAMERAS"); // List of cameras
     if (!mdok || !cameras) {
-        psError(PS_ERR_UNEXPECTED_NULL, true, "Unable to find CAMERAS in the site configuration.\n");
+        psError(PS_ERR_UNEXPECTED_NULL, true, "Unable to find CAMERAS in the system configuration.\n");
         return false;
     }
